==> siujeless-1.0.9.tgz: package/index.js <==
let reuseDate = new Date();
const reuseNow = timestamp => (reuseDate.setTime(timestamp), reuseDate.toISOString());

const log = (logLevel, message) => {
    if (message == undefined) {
        [logLevel, message] = [ "INFO", logLevel ];
    }
    console.log(`[${logLevel}][${reuseNow( Date.now() )}] ${message}`);
}

const qstr = obj=> new URLSearchParams( Object.entries(obj) ).toString();

const siujeless = (...actions) => {
    if (actions.length == 1 && Array.isArray(actions[0])) 
        actions = actions[0];

    if (actions.length == 0) 
        throw new RangeError(`provide at least one parameter as handler`);

    let invalid;
    if (-1 !== (invalid = actions.findIndex(action => typeof action !== "function"))) 
        throw new TypeError(`parameter in ${invalid} expects function`);

    const onFetch = actions.pop();
    const tools = actions;
    const sorry = Promise.resolve("sorry");
    const apply = handler => {
        while (tools.length > 0) {
            const tool = tools.pop();
            const enhanced = handler;
            handler = (req, res) => tool(req, res)(enhanced).catch( err => (res(500), log("ERRR", `request fatal: ${err.stack}`), sorry))
        }
        return handler;
    }

    const chain = apply(onFetch);
    return (request) => new Promise( (ok, reject) => {
        const ctx = {
            status: 404,
            header: {},
            format: null,
        };
        let fullfilled = false;
        const resolve = (response) => {
            if (!fullfilled){
                fullfilled = true;
                ok( response );
            }
        }
        const onfail = reason => {
            log( "ERRR", `request reject: ${reason.stack}`);
            resolve( new Response( reason.message, { status: 500, headers: ctx.header } ) );
        }
        const output = body => {
            let respbody = "", ctype = "";
            if (ctx.format == 'json')
                respbody = JSON.stringify( body ), ctype = "application/json; charset=utf-8";
            else if (ctx.format == 'query')
                respbody = qstr( body );
            else respbody = String(body), ctype = ctx.format ?? "text/plain";
            resolve( new Response(respbody, {
                status: ctx.status,
                headers: {
                    ...ctx.header,
                    ...(ctype ? {"Content-Type": ctype} : {})
                }
            }) );
        }
        const syn = v => {
            const type = typeof v;
            if (type == 'string') {
                ctx.format = v;
            }
            else if (type == 'number') {
                ctx.status = v;
            }
            else if (type instanceof Error) {
                onfail( v );
            }
            else if (type == 'object') {
                ctx.header = Object.assign(ctx.header, v);
            }
            else if (type == 'undefined') {
                return [ctx.status, ctx.header, ctx.format];
            }
            else if (type == 'function') {
                v( resolve );
            }
            return syn;
        }
        chain(request, syn).then( output );
    });
}

Object.defineProperty(siujeless, "log", {
    value: log,
    writable: false,
});

export default siujeless;

==> siujeless-1.0.12.tgz: package/index.js <==
let reuseDate = new Date();
const reuseNow = timestamp => (reuseDate.setTime(timestamp), reuseDate.toISOString());

const log = (logLevel, message) => {
    if (message == undefined) {
        [logLevel, message] = [ "INFO", logLevel ];
    }
    console.log(`[${logLevel}][${reuseNow( Date.now() )}] ${message}`);
}

const qstr = obj=> new URLSearchParams( Object.entries(obj) ).toString();
const sorry = Promise.resolve("sorry");
const seq = (...tools) => handler => {
  while (tools.length > 0) {
    const tool = tools.pop();
    const enhanced = handler;
    handler = (req, res) => tool(req, res)( enhanced ).catch( err => (res(500), log("ERRR", `request fatal: ${err.stack}`), sorry) );
  }
  return handler;
}
const siujeless = (...actions) => {
    if (actions.length == 1 && Array.isArray(actions[0])) 
        actions = actions[0];

    if (actions.length == 0) 
        throw new RangeError(`provide at least one parameter as handler`);

    let invalid;
    if (-1 !== (invalid = actions.findIndex(action => typeof action !== "function"))) 
        throw new TypeError(`parameter in ${invalid} expects function`);

    const onFetch = actions.pop();
    const chain = seq( ...actions )( onFetch );
    return (request) => new Promise( (ok, reject) => {
        const ctx = {
            status: 404,
            header: {},
            format: null,
        };
        let fullfilled = false;
        const resolve = (response) => {
            if (!fullfilled){
                fullfilled = true;
                ok( response );
            }
        }
        const onfail = reason => {
            log( "ERRR", `request reject: ${reason.stack}`);
            resolve( new Response( reason.message, { status: 500, headers: ctx.header } ) );
        }
        const output = body => {
            let respbody = "", ctype = "";
            if (ctx.format == 'json')
                respbody = JSON.stringify( body ), ctype = "application/json; charset=utf-8";
            else if (ctx.format == 'query')
                respbody = qstr( body );
            else respbody = String(body), ctype = ctx.format ?? "text/plain";
            resolve( new Response(respbody, {
                status: ctx.status,
                headers: {
                    ...ctx.header,
                    ...(ctype ? {"Content-Type": ctype} : {})
                }
            }) );
        }
        const syn = v => {
            const type = typeof v;
            if (type == 'string') {
                ctx.format = v;
            }
            else if (type == 'number') {
                ctx.status = v;
            }
            else if (type instanceof Error) {
                onfail( v );
            }
            else if (type == 'object') {
                ctx.header = Object.assign(ctx.header, v);
            }
            else if (type == 'undefined') {
                return [ctx.status, ctx.header, ctx.format];
            }
            else if (type == 'function') {
                v( resolve );
            }
            return syn;
        }
        chain(request, syn).then( output );
    });
}

const method = (key, fun) => Object.defineProperty(siujeless, key, {
    value: fun,
    writable: false,
});

method("log", log);
method("seq", (...tools) => (req, res) => next => seq(...tools)( next )(req, res) );

export default siujeless;
